@@ -8,24 +8,24 @@ class FulfillmentInbound(Client):
         return self._request(kwargs.pop('path'), params=kwargs)
 
     @sp_endpoint("/fba/inbound/v0/plans", method='POST')
-    def plans(self, **kwargs):
-        return self._request(kwargs.pop('path'), data=kwargs)
+    def plans(self, data, **kwargs):
+        return self._request(kwargs.pop('path'), data={**data, **kwargs})
 
     @sp_endpoint("/fba/inbound/v0/shipments/{}", method='POST')
-    def create_shipment(self, shipment_id, **kwargs):
-        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), data=kwargs)
+    def create_shipment(self, shipment_id, data, **kwargs):
+        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), data={**data, **kwargs})
 
     @sp_endpoint("/fba/inbound/v0/shipments/{}", method='PUT')
-    def update_shipment(self, shipment_id, **kwargs):
-        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), data=kwargs)
+    def update_shipment(self, shipment_id, data, **kwargs):
+        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), data={**data, **kwargs})
 
     @sp_endpoint("/fba/inbound/v0/shipments/{}/preorder")
     def preorder(self, shipment_id, **kwargs):
         return self._request(fill_query_params(kwargs.pop('path'), shipment_id), params=kwargs)
 
     @sp_endpoint("/fba/inbound/v0/shipments/{}/preorder/confirm", method='PUT')
-    def confirm_preorder(self, shipment_id, **kwargs):
-        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), params=kwargs)
+    def confirm_preorder(self, shipment_id, data, **kwargs):
+        return self._request(fill_query_params(kwargs.pop('path'), shipment_id), params={**data, **kwargs})
 
     @sp_endpoint("/fba/inbound/v0/prepInstructions")
     def prep_instruction(self, **kwargs):
